

    function _loadWasmBinary (src, imports) {
      var buf = null
      var isNode = typeof process !== 'undefined' && process.versions != null && process.versions.node != null
      if (isNode) {
        buf = Buffer.from(src, 'base64').buffer
      } else {
        var raw = globalThis.atob(src)
        var rawLength = raw.length
        buf = new Uint8Array(new ArrayBuffer(rawLength))
        for(var i = 0; i < rawLength; i++) {
           buf[i] = raw.charCodeAt(i)
        }
      }
      return buf;
    }
    
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var vscodeTextmate = require('vscode-textmate');
var vscodeOniguruma = require('vscode-oniguruma');
var trimEnd = _interopDefault(require('string.prototype.trimend'));

const loadGrammarFile = (scope) => {
    switch (scope) {
        case "source.clojure":
            return Promise.resolve().then(function () { return require('./extensions-clojure-syntaxes-clojure.tmLanguage-5bcdc37b.js'); }).then((m) => m.default);
        case "source.batchfile":
            return Promise.resolve().then(function () { return require('./extensions-bat-syntaxes-batchfile.tmLanguage-8d055660.js'); }).then((m) => m.default);
        case "source.coffee":
            return Promise.resolve().then(function () { return require('./extensions-coffeescript-syntaxes-coffeescript.tmLanguage-90639059.js'); }).then((m) => m.default);
        case "source.dockerfile":
            return Promise.resolve().then(function () { return require('./extensions-docker-syntaxes-docker.tmLanguage-0df6fd68.js'); }).then((m) => m.default);
        case "source.diff":
            return Promise.resolve().then(function () { return require('./extensions-git-syntaxes-diff.tmLanguage-02f0952b.js'); }).then((m) => m.default);
        case "source.go":
            return Promise.resolve().then(function () { return require('./extensions-go-syntaxes-go.tmLanguage-8d0435be.js'); }).then((m) => m.default);
        case "source.ignore":
            return Promise.resolve().then(function () { return require('./extensions-git-syntaxes-ignore.tmLanguage-b5949a17.js'); }).then((m) => m.default);
        case "text.git-rebase":
            return Promise.resolve().then(function () { return require('./extensions-git-syntaxes-git-rebase.tmLanguage-46527945.js'); }).then((m) => m.default);
        case "text.git-commit":
            return Promise.resolve().then(function () { return require('./extensions-git-syntaxes-git-commit.tmLanguage-84900f57.js'); }).then((m) => m.default);
        case "source.fsharp":
            return Promise.resolve().then(function () { return require('./extensions-fsharp-syntaxes-fsharp.tmLanguage-436f53f5.js'); }).then((m) => m.default);
        case "source.groovy":
            return Promise.resolve().then(function () { return require('./extensions-groovy-syntaxes-groovy.tmLanguage-61fe74b8.js'); }).then((m) => m.default);
        case "source.hlsl":
            return Promise.resolve().then(function () { return require('./extensions-hlsl-syntaxes-hlsl.tmLanguage-13a0ca2a.js'); }).then((m) => m.default);
        case "source.c":
            return Promise.resolve().then(function () { return require('./extensions-cpp-syntaxes-c.tmLanguage-ef478384.js'); }).then((m) => m.default);
        case "source.c.platform":
            return Promise.resolve().then(function () { return require('./extensions-cpp-syntaxes-platform.tmLanguage-7f223853.js'); }).then((m) => m.default);
        case "source.css":
            return Promise.resolve().then(function () { return require('./extensions-css-syntaxes-css.tmLanguage-b63ae828.js'); }).then((m) => m.default);
        case "source.cs":
            return Promise.resolve().then(function () { return require('./extensions-csharp-syntaxes-csharp.tmLanguage-b78064b4.js'); }).then((m) => m.default);
        case "text.html.handlebars":
            return Promise.resolve().then(function () { return require('./extensions-handlebars-syntaxes-Handlebars.tmLanguage-2e39efdf.js'); }).then((m) => m.default);
        case "text.html.derivative":
            return Promise.resolve().then(function () { return require('./extensions-html-syntaxes-html-derivative.tmLanguage-b105257d.js'); }).then((m) => m.default);
        case "source.ini":
            return Promise.resolve().then(function () { return require('./extensions-ini-syntaxes-ini.tmLanguage-8358e91a.js'); }).then((m) => m.default);
        case "source.json":
            return Promise.resolve().then(function () { return require('./extensions-json-syntaxes-JSON.tmLanguage-04a801c9.js'); }).then((m) => m.default);
        case "source.json.comments":
            return Promise.resolve().then(function () { return require('./extensions-json-syntaxes-JSONC.tmLanguage-a6fbc9d5.js'); }).then((m) => m.default);
        case "text.log":
            return Promise.resolve().then(function () { return require('./extensions-log-syntaxes-log.tmLanguage-b20ecca7.js'); }).then((m) => m.default);
        case "source.lua":
            return Promise.resolve().then(function () { return require('./extensions-lua-syntaxes-lua.tmLanguage-4923aa89.js'); }).then((m) => m.default);
        case "source.makefile":
            return Promise.resolve().then(function () { return require('./extensions-make-syntaxes-make.tmLanguage-db6c33d9.js'); }).then((m) => m.default);
        case "source.css.less":
            return Promise.resolve().then(function () { return require('./extensions-less-syntaxes-less.tmLanguage-ff3510c0.js'); }).then((m) => m.default);
        case "source.java":
            return Promise.resolve().then(function () { return require('./extensions-java-syntaxes-java.tmLanguage-cc2d9d6f.js'); }).then((m) => m.default);
        case "source.perl.6":
            return Promise.resolve().then(function () { return require('./extensions-perl-syntaxes-perl6.tmLanguage-12701d8e.js'); }).then((m) => m.default);
        case "text.html.basic":
            return Promise.resolve().then(function () { return require('./extensions-html-syntaxes-html.tmLanguage-bc06c357.js'); }).then((m) => m.default);
        case "text.html.markdown":
            return Promise.resolve().then(function () { return require('./extensions-markdown-basics-syntaxes-markdown.tmLanguage-69341eeb.js'); }).then((m) => m.default);
        case "text.html.php":
            return Promise.resolve().then(function () { return require('./extensions-php-syntaxes-html.tmLanguage-76c224a0.js'); }).then((m) => m.default);
        case "source.regexp.python":
            return Promise.resolve().then(function () { return require('./extensions-python-syntaxes-MagicRegExp.tmLanguage-57b0ee31.js'); }).then((m) => m.default);
        case "source.powershell":
            return Promise.resolve().then(function () { return require('./extensions-powershell-syntaxes-powershell.tmLanguage-84b1532e.js'); }).then((m) => m.default);
        case "text.pug":
            return Promise.resolve().then(function () { return require('./extensions-pug-syntaxes-pug.tmLanguage-e7a4aaa4.js'); }).then((m) => m.default);
        case "text.html.cshtml":
            return Promise.resolve().then(function () { return require('./extensions-razor-syntaxes-cshtml.tmLanguage-1cac084b.js'); }).then((m) => m.default);
        case "source.rust":
            return Promise.resolve().then(function () { return require('./extensions-rust-syntaxes-rust.tmLanguage-1396727f.js'); }).then((m) => m.default);
        case "source.sassdoc":
            return Promise.resolve().then(function () { return require('./extensions-scss-syntaxes-sassdoc.tmLanguage-3dd300b0.js'); }).then((m) => m.default);
        case "source.shaderlab":
            return Promise.resolve().then(function () { return require('./extensions-shaderlab-syntaxes-shaderlab.tmLanguage-ef0f4e54.js'); }).then((m) => m.default);
        case "source.perl":
            return Promise.resolve().then(function () { return require('./extensions-perl-syntaxes-perl.tmLanguage-61def0b2.js'); }).then((m) => m.default);
        case "source.r":
            return Promise.resolve().then(function () { return require('./extensions-r-syntaxes-r.tmLanguage-cb502c69.js'); }).then((m) => m.default);
        case "source.shell":
            return Promise.resolve().then(function () { return require('./extensions-shellscript-syntaxes-shell-unix-bash.tmLanguage-59473dfe.js'); }).then((m) => m.default);
        case "source.sql":
            return Promise.resolve().then(function () { return require('./extensions-sql-syntaxes-sql.tmLanguage-1d97b741.js'); }).then((m) => m.default);
        case "source.css.scss":
            return Promise.resolve().then(function () { return require('./extensions-scss-syntaxes-scss.tmLanguage-f7e9a948.js'); }).then((m) => m.default);
        case "documentation.injection":
            return Promise.resolve().then(function () { return require('./extensions-typescript-basics-syntaxes-jsdoc.injection.tmLanguage-45fdce4d.js'); }).then((m) => m.default);
        case "source.ruby":
            return Promise.resolve().then(function () { return require('./extensions-ruby-syntaxes-ruby.tmLanguage-a067beb2.js'); }).then((m) => m.default);
        case "text.xml.xsl":
            return Promise.resolve().then(function () { return require('./extensions-xml-syntaxes-xsl.tmLanguage-9ad992ea.js'); }).then((m) => m.default);
        case "text.xml":
            return Promise.resolve().then(function () { return require('./extensions-xml-syntaxes-xml.tmLanguage-9d79af73.js'); }).then((m) => m.default);
        case "source.python":
            return Promise.resolve().then(function () { return require('./extensions-python-syntaxes-MagicPython.tmLanguage-674cd621.js'); }).then((m) => m.default);
        case "source.yaml":
            return Promise.resolve().then(function () { return require('./extensions-yaml-syntaxes-yaml.tmLanguage-92570cbf.js'); }).then((m) => m.default);
        case "source.js":
            return Promise.resolve().then(function () { return require('./extensions-javascript-syntaxes-JavaScript.tmLanguage-f8bf60d3.js'); }).then((m) => m.default);
        case "source.js.jsx":
            return Promise.resolve().then(function () { return require('./extensions-javascript-syntaxes-JavaScriptReact.tmLanguage-56e03400.js'); }).then((m) => m.default);
        case "source.objc":
            return Promise.resolve().then(function () { return require('./extensions-objective-c-syntaxes-objective-c.tmLanguage-0f05ec0f.js'); }).then((m) => m.default);
        case "source.php":
            return Promise.resolve().then(function () { return require('./extensions-php-syntaxes-php.tmLanguage-31b1339e.js'); }).then((m) => m.default);
        case "source.swift":
            return Promise.resolve().then(function () { return require('./extensions-swift-syntaxes-swift.tmLanguage-1786b68d.js'); }).then((m) => m.default);
        case "source.tsx":
            return Promise.resolve().then(function () { return require('./extensions-typescript-basics-syntaxes-TypeScriptReact.tmLanguage-5b446248.js'); }).then((m) => m.default);
        case "source.objcpp":
            return Promise.resolve().then(function () { return require('./extensions-objective-c-syntaxes-objective-c++.tmLanguage-673e41ca.js'); }).then((m) => m.default);
        case "source.ts":
            return Promise.resolve().then(function () { return require('./extensions-typescript-basics-syntaxes-TypeScript.tmLanguage-f7bdb08e.js'); }).then((m) => m.default);
        case "source.cpp.embedded.macro":
            return Promise.resolve().then(function () { return require('./extensions-cpp-syntaxes-cpp.embedded.macro.tmLanguage-0b3358a0.js'); }).then((m) => m.default);
        case "source.cpp":
            return Promise.resolve().then(function () { return require('./extensions-cpp-syntaxes-cpp.tmLanguage-4f94f418.js'); }).then((m) => m.default);
        case "source.jsonnet":
            return Promise.resolve().then(function () { return require('./jsonnet.tmLanguage-8f762009.js'); }).then((m) => m.default);
        default:
            return Promise.resolve(null);
    }
};
const getLang = (lang) => {
    switch (lang) {
        case "source.clojure":
            return "source.clojure";
        case "source.batchfile":
            return "source.batchfile";
        case "source.coffee":
            return "source.coffee";
        case "source.dockerfile":
            return "source.dockerfile";
        case "source.diff":
            return "source.diff";
        case "source.go":
            return "source.go";
        case "source.ignore":
            return "source.ignore";
        case "text.git-rebase":
            return "text.git-rebase";
        case "text.git-commit":
            return "text.git-commit";
        case "source.fsharp":
            return "source.fsharp";
        case "fsharp":
            return "source.fsharp";
        case "fsx":
            return "source.fsharp";
        case "fs":
            return "source.fsharp";
        case "source.groovy":
            return "source.groovy";
        case "source.hlsl":
            return "source.hlsl";
        case "source.c":
            return "source.c";
        case "source.c.platform":
            return "source.c.platform";
        case "source.css":
            return "source.css";
        case "source.cs":
            return "source.cs";
        case "c#":
            return "source.cs";
        case "csharp":
            return "source.cs";
        case "dotnet":
            return "source.cs";
        case "text.html.handlebars":
            return "text.html.handlebars";
        case "text.html.derivative":
            return "text.html.derivative";
        case "source.ini":
            return "source.ini";
        case "source.json":
            return "source.json";
        case "json":
            return "source.json";
        case "source.json.comments":
            return "source.json.comments";
        case "text.log":
            return "text.log";
        case "source.lua":
            return "source.lua";
        case "source.makefile":
            return "source.makefile";
        case "source.css.less":
            return "source.css.less";
        case "source.java":
            return "source.java";
        case "source.perl.6":
            return "source.perl.6";
        case "text.html.basic":
            return "text.html.basic";
        case "text.html.markdown":
            return "text.html.markdown";
        case "markdown":
            return "text.html.markdown";
        case "md":
            return "text.html.markdown";
        case "text.html.php":
            return "text.html.php";
        case "source.regexp.python":
            return "source.regexp.python";
        case "source.powershell":
            return "source.powershell";
        case "text.pug":
            return "text.pug";
        case "text.html.cshtml":
            return "text.html.cshtml";
        case "source.rust":
            return "source.rust";
        case "rust":
            return "source.rust";
        case "source.sassdoc":
            return "source.sassdoc";
        case "source.shaderlab":
            return "source.shaderlab";
        case "source.perl":
            return "source.perl";
        case "source.r":
            return "source.r";
        case "source.shell":
            return "source.shell";
        case "source.sql":
            return "source.sql";
        case "source.css.scss":
            return "source.css.scss";
        case "documentation.injection":
            return "documentation.injection";
        case "source.ruby":
            return "source.ruby";
        case "text.xml.xsl":
            return "text.xml.xsl";
        case "text.xml":
            return "text.xml";
        case "source.python":
            return "source.python";
        case "source.yaml":
            return "source.yaml";
        case "source.js":
            return "source.js";
        case "source.js.jsx":
            return "source.js.jsx";
        case "source.objc":
            return "source.objc";
        case "source.php":
            return "source.php";
        case "source.swift":
            return "source.swift";
        case "source.tsx":
            return "source.tsx";
        case "source.objcpp":
            return "source.objcpp";
        case "source.ts":
            return "source.ts";
        case "source.cpp.embedded.macro":
            return "source.cpp.embedded.macro";
        case "source.cpp":
            return "source.cpp";
        case "source.jsonnet":
            return "source.jsonnet";
        case "jsonnet":
            return "source.jsonnet";
        case "libjsonnet":
            return "source.jsonnet";
        default:
            return null;
    }
};

const loadGrammar = async (scopeName) => {
    const content = await loadGrammarFile(scopeName);
    if (!content)
        return null;
    return vscodeTextmate.parseRawGrammar(content, `${scopeName}.tmLanguage.json`);
};
let onigLib = null;
const loadOnigLib = () => {
    if (onigLib !== null)
        return onigLib;
    return (onigLib = (async () => {
        const { default: wasmRaw } = await Promise.resolve().then(function () { return require('./onig-a88e5b36.js'); });
        try {
            await vscodeOniguruma.loadWASM(wasmRaw());
        }
        catch (e) { }
        return {
            createOnigScanner: (sources) => new vscodeOniguruma.OnigScanner(sources),
            createOnigString: (str) => new vscodeOniguruma.OnigString(str),
        };
    })());
};
let registry = null;
const getRegistry = () => {
    if (registry !== null)
        return registry;
    return (registry = new vscodeTextmate.Registry({
        onigLib: loadOnigLib(),
        loadGrammar: loadGrammar,
    }));
};
const lines = (content) => {
    return content.split('\n').map((l) => trimEnd(l));
};
function* tokenizeInner(source, grammar) {
    let ruleStack = vscodeTextmate.INITIAL;
    const scopeStack = [];
    for (const line of lines(source)) {
        const { tokens, ruleStack: nextRuleStack } = grammar.tokenizeLine(line, ruleStack);
        for (const token of tokens) {
            while (scopeStack.length > token.scopes.length ||
                scopeStack[scopeStack.length - 1] !== token.scopes[scopeStack.length - 1]) {
                const scope = scopeStack.pop();
                yield { type: 'end', scope };
            }
            for (const scope of token.scopes.slice(scopeStack.length)) {
                yield { type: 'start', scope };
                scopeStack.push(scope);
            }
            const text = line.substring(token.startIndex, token.endIndex);
            yield { type: 'token', text, scopes: token.scopes };
        }
        ruleStack = nextRuleStack;
        yield { type: 'line' };
    }
    while (scopeStack.length > 0) {
        const scope = scopeStack.pop();
        yield { type: 'end', scope };
    }
}
const tokenize = async (source, lang) => {
    const scopeName = getLang(lang);
    if (!scopeName)
        return null;
    const grammar = await getRegistry().loadGrammar(scopeName);
    if (!grammar)
        return null;
    return tokenizeInner(source, grammar);
};

exports.tokenize = tokenize;
