

    function _loadWasmBinary (src, imports) {
      var buf = null
      var isNode = typeof process !== 'undefined' && process.versions != null && process.versions.node != null
      if (isNode) {
        buf = Buffer.from(src, 'base64').buffer
      } else {
        var raw = globalThis.atob(src)
        var rawLength = raw.length
        buf = new Uint8Array(new ArrayBuffer(rawLength))
        for(var i = 0; i < rawLength; i++) {
           buf[i] = raw.charCodeAt(i)
        }
      }
      return buf;
    }
    
import { Registry, parseRawGrammar, INITIAL } from 'vscode-textmate';
import { loadWASM, OnigScanner, OnigString } from 'vscode-oniguruma';
import trimEnd from 'string.prototype.trimend';

const loadGrammarFile = (scope) => {
    switch (scope) {
        case "source.clojure":
            return import('./extensions-clojure-syntaxes-clojure.tmLanguage-987a3254.js').then((m) => m.default);
        case "source.batchfile":
            return import('./extensions-bat-syntaxes-batchfile.tmLanguage-de1a2900.js').then((m) => m.default);
        case "source.coffee":
            return import('./extensions-coffeescript-syntaxes-coffeescript.tmLanguage-7f6e39b1.js').then((m) => m.default);
        case "source.dockerfile":
            return import('./extensions-docker-syntaxes-docker.tmLanguage-c56f41b1.js').then((m) => m.default);
        case "source.diff":
            return import('./extensions-git-syntaxes-diff.tmLanguage-bb754939.js').then((m) => m.default);
        case "source.go":
            return import('./extensions-go-syntaxes-go.tmLanguage-9e13de3f.js').then((m) => m.default);
        case "source.ignore":
            return import('./extensions-git-syntaxes-ignore.tmLanguage-1998b962.js').then((m) => m.default);
        case "text.git-rebase":
            return import('./extensions-git-syntaxes-git-rebase.tmLanguage-eed00842.js').then((m) => m.default);
        case "text.git-commit":
            return import('./extensions-git-syntaxes-git-commit.tmLanguage-b4986b59.js').then((m) => m.default);
        case "source.fsharp":
            return import('./extensions-fsharp-syntaxes-fsharp.tmLanguage-64ab37a4.js').then((m) => m.default);
        case "source.groovy":
            return import('./extensions-groovy-syntaxes-groovy.tmLanguage-225a0707.js').then((m) => m.default);
        case "source.hlsl":
            return import('./extensions-hlsl-syntaxes-hlsl.tmLanguage-d76884cd.js').then((m) => m.default);
        case "source.c":
            return import('./extensions-cpp-syntaxes-c.tmLanguage-36f0093c.js').then((m) => m.default);
        case "source.c.platform":
            return import('./extensions-cpp-syntaxes-platform.tmLanguage-aa9e5a0e.js').then((m) => m.default);
        case "source.css":
            return import('./extensions-css-syntaxes-css.tmLanguage-c78477b7.js').then((m) => m.default);
        case "source.cs":
            return import('./extensions-csharp-syntaxes-csharp.tmLanguage-a98ca85c.js').then((m) => m.default);
        case "text.html.handlebars":
            return import('./extensions-handlebars-syntaxes-Handlebars.tmLanguage-4336b3af.js').then((m) => m.default);
        case "text.html.derivative":
            return import('./extensions-html-syntaxes-html-derivative.tmLanguage-b9d07391.js').then((m) => m.default);
        case "source.ini":
            return import('./extensions-ini-syntaxes-ini.tmLanguage-2d1d5592.js').then((m) => m.default);
        case "source.json":
            return import('./extensions-json-syntaxes-JSON.tmLanguage-0c582511.js').then((m) => m.default);
        case "source.json.comments":
            return import('./extensions-json-syntaxes-JSONC.tmLanguage-0abd22db.js').then((m) => m.default);
        case "text.log":
            return import('./extensions-log-syntaxes-log.tmLanguage-0d33c79d.js').then((m) => m.default);
        case "source.lua":
            return import('./extensions-lua-syntaxes-lua.tmLanguage-b55acacd.js').then((m) => m.default);
        case "source.makefile":
            return import('./extensions-make-syntaxes-make.tmLanguage-6bf66fa2.js').then((m) => m.default);
        case "source.css.less":
            return import('./extensions-less-syntaxes-less.tmLanguage-e2a75dfb.js').then((m) => m.default);
        case "source.java":
            return import('./extensions-java-syntaxes-java.tmLanguage-ae6f0387.js').then((m) => m.default);
        case "source.perl.6":
            return import('./extensions-perl-syntaxes-perl6.tmLanguage-d0ebf88a.js').then((m) => m.default);
        case "text.html.basic":
            return import('./extensions-html-syntaxes-html.tmLanguage-d7a6229f.js').then((m) => m.default);
        case "text.html.markdown":
            return import('./extensions-markdown-basics-syntaxes-markdown.tmLanguage-24607d13.js').then((m) => m.default);
        case "text.html.php":
            return import('./extensions-php-syntaxes-html.tmLanguage-b6577396.js').then((m) => m.default);
        case "source.regexp.python":
            return import('./extensions-python-syntaxes-MagicRegExp.tmLanguage-0a3a07f8.js').then((m) => m.default);
        case "source.powershell":
            return import('./extensions-powershell-syntaxes-powershell.tmLanguage-686ea579.js').then((m) => m.default);
        case "text.pug":
            return import('./extensions-pug-syntaxes-pug.tmLanguage-ff833773.js').then((m) => m.default);
        case "text.html.cshtml":
            return import('./extensions-razor-syntaxes-cshtml.tmLanguage-991148ed.js').then((m) => m.default);
        case "source.rust":
            return import('./extensions-rust-syntaxes-rust.tmLanguage-45120193.js').then((m) => m.default);
        case "source.sassdoc":
            return import('./extensions-scss-syntaxes-sassdoc.tmLanguage-80f15ffe.js').then((m) => m.default);
        case "source.shaderlab":
            return import('./extensions-shaderlab-syntaxes-shaderlab.tmLanguage-f7ad2078.js').then((m) => m.default);
        case "source.perl":
            return import('./extensions-perl-syntaxes-perl.tmLanguage-463d1c72.js').then((m) => m.default);
        case "source.r":
            return import('./extensions-r-syntaxes-r.tmLanguage-ebade647.js').then((m) => m.default);
        case "source.shell":
            return import('./extensions-shellscript-syntaxes-shell-unix-bash.tmLanguage-c6f81c5a.js').then((m) => m.default);
        case "source.sql":
            return import('./extensions-sql-syntaxes-sql.tmLanguage-74f46b13.js').then((m) => m.default);
        case "source.css.scss":
            return import('./extensions-scss-syntaxes-scss.tmLanguage-e6f096c2.js').then((m) => m.default);
        case "documentation.injection":
            return import('./extensions-typescript-basics-syntaxes-jsdoc.injection.tmLanguage-e8902746.js').then((m) => m.default);
        case "source.ruby":
            return import('./extensions-ruby-syntaxes-ruby.tmLanguage-c60beb2b.js').then((m) => m.default);
        case "text.xml.xsl":
            return import('./extensions-xml-syntaxes-xsl.tmLanguage-c9679931.js').then((m) => m.default);
        case "text.xml":
            return import('./extensions-xml-syntaxes-xml.tmLanguage-21dcf634.js').then((m) => m.default);
        case "source.python":
            return import('./extensions-python-syntaxes-MagicPython.tmLanguage-72aace5f.js').then((m) => m.default);
        case "source.yaml":
            return import('./extensions-yaml-syntaxes-yaml.tmLanguage-3b6b97dc.js').then((m) => m.default);
        case "source.js":
            return import('./extensions-javascript-syntaxes-JavaScript.tmLanguage-2d7359fd.js').then((m) => m.default);
        case "source.js.jsx":
            return import('./extensions-javascript-syntaxes-JavaScriptReact.tmLanguage-d6b4da5d.js').then((m) => m.default);
        case "source.objc":
            return import('./extensions-objective-c-syntaxes-objective-c.tmLanguage-4a4c16f3.js').then((m) => m.default);
        case "source.php":
            return import('./extensions-php-syntaxes-php.tmLanguage-f1111e3a.js').then((m) => m.default);
        case "source.swift":
            return import('./extensions-swift-syntaxes-swift.tmLanguage-b34f307e.js').then((m) => m.default);
        case "source.tsx":
            return import('./extensions-typescript-basics-syntaxes-TypeScriptReact.tmLanguage-fc87f7e4.js').then((m) => m.default);
        case "source.objcpp":
            return import('./extensions-objective-c-syntaxes-objective-c++.tmLanguage-1a849701.js').then((m) => m.default);
        case "source.ts":
            return import('./extensions-typescript-basics-syntaxes-TypeScript.tmLanguage-b1ee8d6a.js').then((m) => m.default);
        case "source.cpp.embedded.macro":
            return import('./extensions-cpp-syntaxes-cpp.embedded.macro.tmLanguage-1bd130c7.js').then((m) => m.default);
        case "source.cpp":
            return import('./extensions-cpp-syntaxes-cpp.tmLanguage-c0cc1952.js').then((m) => m.default);
        case "source.jsonnet":
            return import('./jsonnet.tmLanguage-5994b342.js').then((m) => m.default);
        default:
            return Promise.resolve(null);
    }
};
const getLang = (lang) => {
    switch (lang) {
        case "source.clojure":
            return "source.clojure";
        case "source.batchfile":
            return "source.batchfile";
        case "source.coffee":
            return "source.coffee";
        case "source.dockerfile":
            return "source.dockerfile";
        case "source.diff":
            return "source.diff";
        case "source.go":
            return "source.go";
        case "source.ignore":
            return "source.ignore";
        case "text.git-rebase":
            return "text.git-rebase";
        case "text.git-commit":
            return "text.git-commit";
        case "source.fsharp":
            return "source.fsharp";
        case "fsharp":
            return "source.fsharp";
        case "fsx":
            return "source.fsharp";
        case "fs":
            return "source.fsharp";
        case "source.groovy":
            return "source.groovy";
        case "source.hlsl":
            return "source.hlsl";
        case "source.c":
            return "source.c";
        case "source.c.platform":
            return "source.c.platform";
        case "source.css":
            return "source.css";
        case "source.cs":
            return "source.cs";
        case "c#":
            return "source.cs";
        case "csharp":
            return "source.cs";
        case "dotnet":
            return "source.cs";
        case "text.html.handlebars":
            return "text.html.handlebars";
        case "text.html.derivative":
            return "text.html.derivative";
        case "source.ini":
            return "source.ini";
        case "source.json":
            return "source.json";
        case "json":
            return "source.json";
        case "source.json.comments":
            return "source.json.comments";
        case "text.log":
            return "text.log";
        case "source.lua":
            return "source.lua";
        case "source.makefile":
            return "source.makefile";
        case "source.css.less":
            return "source.css.less";
        case "source.java":
            return "source.java";
        case "source.perl.6":
            return "source.perl.6";
        case "text.html.basic":
            return "text.html.basic";
        case "text.html.markdown":
            return "text.html.markdown";
        case "markdown":
            return "text.html.markdown";
        case "md":
            return "text.html.markdown";
        case "text.html.php":
            return "text.html.php";
        case "source.regexp.python":
            return "source.regexp.python";
        case "source.powershell":
            return "source.powershell";
        case "text.pug":
            return "text.pug";
        case "text.html.cshtml":
            return "text.html.cshtml";
        case "source.rust":
            return "source.rust";
        case "rust":
            return "source.rust";
        case "source.sassdoc":
            return "source.sassdoc";
        case "source.shaderlab":
            return "source.shaderlab";
        case "source.perl":
            return "source.perl";
        case "source.r":
            return "source.r";
        case "source.shell":
            return "source.shell";
        case "source.sql":
            return "source.sql";
        case "source.css.scss":
            return "source.css.scss";
        case "documentation.injection":
            return "documentation.injection";
        case "source.ruby":
            return "source.ruby";
        case "text.xml.xsl":
            return "text.xml.xsl";
        case "text.xml":
            return "text.xml";
        case "source.python":
            return "source.python";
        case "source.yaml":
            return "source.yaml";
        case "source.js":
            return "source.js";
        case "source.js.jsx":
            return "source.js.jsx";
        case "source.objc":
            return "source.objc";
        case "source.php":
            return "source.php";
        case "source.swift":
            return "source.swift";
        case "source.tsx":
            return "source.tsx";
        case "source.objcpp":
            return "source.objcpp";
        case "source.ts":
            return "source.ts";
        case "source.cpp.embedded.macro":
            return "source.cpp.embedded.macro";
        case "source.cpp":
            return "source.cpp";
        case "source.jsonnet":
            return "source.jsonnet";
        case "jsonnet":
            return "source.jsonnet";
        case "libjsonnet":
            return "source.jsonnet";
        default:
            return null;
    }
};

const loadGrammar = async (scopeName) => {
    const content = await loadGrammarFile(scopeName);
    if (!content)
        return null;
    return parseRawGrammar(content, `${scopeName}.tmLanguage.json`);
};
let onigLib = null;
const loadOnigLib = () => {
    if (onigLib !== null)
        return onigLib;
    return (onigLib = (async () => {
        const { default: wasmRaw } = await import('./onig-1dcb1caa.js');
        try {
            await loadWASM(wasmRaw());
        }
        catch (e) { }
        return {
            createOnigScanner: (sources) => new OnigScanner(sources),
            createOnigString: (str) => new OnigString(str),
        };
    })());
};
let registry = null;
const getRegistry = () => {
    if (registry !== null)
        return registry;
    return (registry = new Registry({
        onigLib: loadOnigLib(),
        loadGrammar: loadGrammar,
    }));
};
const lines = (content) => {
    return content.split('\n').map((l) => trimEnd(l));
};
function* tokenizeInner(source, grammar) {
    let ruleStack = INITIAL;
    const scopeStack = [];
    for (const line of lines(source)) {
        const { tokens, ruleStack: nextRuleStack } = grammar.tokenizeLine(line, ruleStack);
        for (const token of tokens) {
            while (scopeStack.length > token.scopes.length ||
                scopeStack[scopeStack.length - 1] !== token.scopes[scopeStack.length - 1]) {
                const scope = scopeStack.pop();
                yield { type: 'end', scope };
            }
            for (const scope of token.scopes.slice(scopeStack.length)) {
                yield { type: 'start', scope };
                scopeStack.push(scope);
            }
            const text = line.substring(token.startIndex, token.endIndex);
            yield { type: 'token', text, scopes: token.scopes };
        }
        ruleStack = nextRuleStack;
        yield { type: 'line' };
    }
    while (scopeStack.length > 0) {
        const scope = scopeStack.pop();
        yield { type: 'end', scope };
    }
}
const tokenize = async (source, lang) => {
    const scopeName = getLang(lang);
    if (!scopeName)
        return null;
    const grammar = await getRegistry().loadGrammar(scopeName);
    if (!grammar)
        return null;
    return tokenizeInner(source, grammar);
};

export { tokenize };
